@@ -16,7 +16,6 @@
 
 import sys
 import logging
-import uuid
 import pprint
 import json
 import copy
@@ -210,7 +209,7 @@ def main():
     # HACK HACK HACK - allow required config params to be passed
     # via the command line
     cfg.CONF['service:api']._group._opts['api_base_uri']['cli'] = True
-    for optdict in cfg.CONF['backend:ipa']._group._opts.itervalues():
+    for optdict in cfg.CONF['backend:ipa']._group._opts.values():
         if 'cli' in optdict:
             optdict['cli'] = True
     # HACK HACK HACK - allow api url to be passed in the usual way
@@ -264,7 +263,7 @@ def main():
     assert(zone)
 
     # create a fake subdomain of this zone
-    domname = "%s.%s" % (uuid.uuid4(), zone['idnsname'])
+    domname = "%s.%s" % (utils.generate_uuid(), zone['idnsname'])
     args = copy.copy(zone)
     del args['idnsname']
     args['version'] = version
@@ -362,4 +361,4 @@ def main():
                                           pprint.pformat(resp.json())))
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
