@@ -91,6 +91,12 @@ class ContextMiddleware(base.Middleware):
                 value = request.GET.pop(i)
                 ctxt.all_tenants = strutils.bool_from_string(value)
 
+    def _extract_dns_hide_counts(self, ctxt, request):
+        ctxt.hide_counts = False
+        value = request.headers.get('OpenStack-DNS-Hide-Counts')
+        if value:
+            ctxt.hide_counts = strutils.bool_from_string(value)
+
     def _extract_edit_managed_records(self, ctxt, request):
         ctxt.edit_managed_records = False
         if 'edit_managed_records' in request.GET:
@@ -101,6 +107,10 @@ class ContextMiddleware(base.Middleware):
                 strutils.bool_from_string(
                     request.headers.get('X-Designate-Edit-Managed-Records'))
 
+    def _extract_client_addr(self, ctxt, request):
+        if hasattr(request, 'client_addr'):
+            ctxt.client_addr = request.client_addr
+
     def make_context(self, request, *args, **kwargs):
         req_id = request.environ.get(request_id.ENV_REQUEST_ID)
         kwargs.setdefault('request_id', req_id)
@@ -111,6 +121,8 @@ class ContextMiddleware(base.Middleware):
             self._extract_sudo(ctxt, request)
             self._extract_all_projects(ctxt, request)
             self._extract_edit_managed_records(ctxt, request)
+            self._extract_dns_hide_counts(ctxt, request)
+            self._extract_client_addr(ctxt, request)
         finally:
             request.environ['context'] = ctxt
         return ctxt
