@@ -18,12 +18,13 @@
 
 import math
 import time
-import uuid
 
 from oslo_config import cfg
 from oslo_log import log
+import retrying
 import tooz.coordination
 
+from designate.utils import generate_uuid
 from designate.i18n import _LI
 from designate.i18n import _LW
 from designate.i18n import _LE
@@ -51,6 +52,11 @@ cfg.CONF.register_opts(OPTS, group='coordination')
 CONF = cfg.CONF
 
 
+def _retry_if_tooz_error(exception):
+    """Return True if we should retry, False otherwise"""
+    return isinstance(exception, tooz.coordination.ToozError)
+
+
 class CoordinationMixin(object):
     def __init__(self, *args, **kwargs):
         super(CoordinationMixin, self).__init__(*args, **kwargs)
@@ -58,7 +64,7 @@ class CoordinationMixin(object):
         self._coordinator = None
 
     def start(self):
-        self._coordination_id = ":".join([CONF.host, str(uuid.uuid4())])
+        self._coordination_id = ":".join([CONF.host, generate_uuid()])
 
         if CONF.coordination.backend_url is not None:
             backend_url = cfg.CONF.coordination.backend_url
@@ -99,7 +105,7 @@ class CoordinationMixin(object):
 
                 except Exception:
                     LOG.warning(_LW("Failed to start Coordinator:"),
-                             exc_info=True)
+                                exc_info=True)
                     time.sleep(15)
 
     def stop(self):
@@ -147,6 +153,8 @@ class Partitioner(object):
                         'the only worker. Please configure a coordination '
                         'backend'))
 
+    @retrying.retry(stop_max_attempt_number=5, wait_random_max=2000,
+                    retry_on_exception=_retry_if_tooz_error)
     def _get_members(self, group_id):
         get_members_req = self._coordinator.get_members(group_id)
         try:
@@ -155,6 +163,11 @@ class Partitioner(object):
         except tooz.coordination.GroupNotCreated:
             LOG.error(_LE('Attempting to partition over a non-existent group: '
                           '%s'), self._group_id)
+
+            raise
+        except tooz.coordination.ToozError:
+            LOG.error(_LE('Error getting group membership info from '
+                          'coordination backend.'))
             raise
 
     def _on_group_change(self, event):
@@ -261,16 +274,9 @@ class LeaderElection(object):
             LOG.info(_LI('Stopping leader election for group %(group)s'),
                      {'group': self._group_id})
 
-            try:
-                # Remove the elected_as_leader callback
-                self._coordinator.unwatch_elected_as_leader(
-                    self._group_id, self._on_elected_leader)
-
-            except AttributeError:
-                # TODO(kiall): Remove when tooz bug #1467907 is fixed +
-                #              released, and is in our requirements.
-                if not self._coordinator._hooks_elected_leader[self._group_id]:
-                    del self._coordinator._hooks_elected_leader[self._group_id]
+            # Remove the elected_as_leader callback
+            self._coordinator.unwatch_elected_as_leader(
+                self._group_id, self._on_elected_leader)
 
             if self._leader:
                 # Tell Tooz we no longer wish to be the leader
@@ -289,7 +295,7 @@ class LeaderElection(object):
         return self._leader
 
     def _on_elected_leader(self, event):
-        LOG.info(_LI('Sucessfully elected as leader of group %(group)s'),
+        LOG.info(_LI('Successfully elected as leader of group %(group)s'),
                  {'group': self._group_id})
         self._leader = True
 
