@@ -13,6 +13,8 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
+import sys
+
 import yaml
 from oslo_config import cfg
 from oslo_log import log as logging
@@ -40,14 +42,15 @@ class PoolCommands(base.Commands):
         self.central_api = central_rpcapi.CentralAPI()
 
     @base.args('--file', help='The path to the file the yaml output should be '
-               'writen to',
+               'written to',
                default='/etc/designate/pools.yaml')
     def generate_file(self, file):
         try:
             pools = self.central_api.find_pools(self.context)
         except messaging.exceptions.MessagingTimeout:
-            LOG.critical(_LC("No response recieved from designate-central. "
+            LOG.critical(_LC("No response received from designate-central. "
                              "Check it is running, and retry"))
+            sys.exit(1)
         with open(file, 'w') as stream:
             yaml.dump(
                 DesignateAdapter.render('YAML', pools),
@@ -62,8 +65,9 @@ class PoolCommands(base.Commands):
         try:
             pools = self.central_api.find_pools(self.context)
         except messaging.exceptions.MessagingTimeout:
-            LOG.critical(_LC("No response recieved from designate-central. "
+            LOG.critical(_LC("No response received from designate-central. "
                              "Check it is running, and retry"))
+            sys.exit(1)
         r_pools = objects.PoolList()
         for pool in pools:
             r_pool = objects.Pool.from_config(CONF, pool.id)
@@ -91,8 +95,9 @@ class PoolCommands(base.Commands):
                   default_flow_style=False))
 
         except messaging.exceptions.MessagingTimeout:
-            LOG.critical(_LC("No response recieved from designate-central. "
+            LOG.critical(_LC("No response received from designate-central. "
                              "Check it is running, and retry"))
+            sys.exit(1)
 
     @base.args('--file', help='The path to the yaml file describing the pools',
                default='/etc/designate/pools.yaml')
@@ -108,7 +113,6 @@ class PoolCommands(base.Commands):
     def update(self, file, delete, dry_run):
         print('Updating Pools Configuration')
         print('****************************')
-
         output_msg = ['']
 
         with open(file, 'r') as stream:
@@ -138,6 +142,16 @@ class PoolCommands(base.Commands):
 
                 pool = DesignateAdapter.parse('YAML', xpool, pool)
 
+                # TODO(graham): We should be doing a full validation, but right
+                # now there is quirks validating through nested objects.
+
+                for ns_record in pool.ns_records:
+                    try:
+                        ns_record.validate()
+                    except exceptions.InvalidObject as e:
+                        LOG.error(e.errors.to_list()[0]['message'])
+                        sys.exit(1)
+
                 if dry_run:
                     output_msg.append("Update Pool: %s" % pool)
                 else:
@@ -145,15 +159,21 @@ class PoolCommands(base.Commands):
 
             except exceptions.PoolNotFound:
                 pool = DesignateAdapter.parse('YAML', xpool, objects.Pool())
-                # pool = objects.Pool.from_dict(xpool)
+                for ns_record in pool.ns_records:
+                    try:
+                        ns_record.validate()
+                    except exceptions.InvalidObject as e:
+                        LOG.error(e.errors.to_list()[0]['message'])
+                        sys.exit(1)
                 if dry_run:
                     output_msg.append("Create Pool: %s" % pool)
                 else:
                     LOG.info(_LI('Creating new pool: %s'), pool)
                     self.central_api.create_pool(self.context, pool)
             except messaging.exceptions.MessagingTimeout:
-                LOG.critical(_LC("No response recieved from designate-central."
+                LOG.critical(_LC("No response received from designate-central."
                                  " Check it is running, and retry"))
+                sys.exit(1)
 
         if delete:
             pools = self.central_api.find_pools(self.context)
@@ -176,9 +196,10 @@ class PoolCommands(base.Commands):
                         self.central_api.delete_pool(self.context, p.id)
 
                 except messaging.exceptions.MessagingTimeout:
-                    LOG.critical(_LC("No response recieved from "
+                    LOG.critical(_LC("No response received from "
                                      "designate-central. "
                                      "Check it is running, and retry"))
+                    sys.exit(1)
 
         for line in output_msg:
             print(line)
