@@ -13,17 +13,16 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-import uuid
-
 import six
 from oslo_log import log as logging
 
-from designate.network_api.base import NetworkAPI
+from designate.utils import generate_uuid
+from designate.network_api import base
 
 
 LOG = logging.getLogger(__name__)
 
-POOL = dict([(str(uuid.uuid4()), '192.168.2.%s' % i) for i in
+POOL = dict([(generate_uuid(), '192.168.2.%s' % i) for i in
              range(0, 254)])
 ALLOCATIONS = {}
 
@@ -70,7 +69,7 @@ def reset_floatingips():
             POOL[key] = allocated.pop(key)
 
 
-class FakeNetworkAPI(NetworkAPI):
+class FakeNetworkAPI(base.NetworkAPI):
     __plugin_name__ = 'fake'
 
     def list_floatingips(self, context, region=None):
