@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-#
 # Copyright 2012 OpenStack Foundation
 # All Rights Reserved
 #
@@ -26,7 +24,7 @@ from oslo_service import threadgroup
 from designate import exceptions
 from designate.i18n import _LW
 from designate.i18n import _LE
-from designate.network_api.base import NetworkAPI
+from designate.network_api import base
 
 
 CONF = cfg.CONF
@@ -36,7 +34,7 @@ LOG = logging.getLogger(__name__)
 neutron_opts = [
     cfg.ListOpt('endpoints',
                 help='URL to use if None in the ServiceCatalog that is '
-                'passed by the requrest context. Format: <region>|<url>'),
+                'passed by the request context. Format: <region>|<url>'),
     cfg.StrOpt('endpoint_type', default='publicURL',
                help="Endpoint type to use"),
     cfg.IntOpt('timeout',
@@ -86,7 +84,7 @@ def get_client(context, endpoint):
     return clientv20.Client(**params)
 
 
-class NeutronNetworkAPI(NetworkAPI):
+class NeutronNetworkAPI(base.NetworkAPI):
     """
     Interact with the Neutron API
     """
