@@ -16,7 +16,7 @@
 from oslo_config import cfg
 from oslo_log import log as logging
 
-from designate.notification_handler.base import BaseAddressHandler
+from designate.notification_handler import base
 
 
 LOG = logging.getLogger(__name__)
@@ -30,12 +30,15 @@ cfg.CONF.register_opts([
     cfg.ListOpt('notification-topics', default=['notifications']),
     cfg.StrOpt('control-exchange', default='neutron'),
     cfg.StrOpt('zone-id'),
-    cfg.MultiStrOpt('format', default=[
-                    '%(octet0)s-%(octet1)s-%(octet2)s-%(octet3)s.%(zone)s'])
+    cfg.MultiStrOpt('formatv4'),
+    cfg.MultiStrOpt('format', deprecated_for_removal=True,
+                    deprecated_reason="Replaced by 'formatv4/formatv6'",
+                    ),
+    cfg.MultiStrOpt('formatv6')
 ], group='handler:neutron_floatingip')
 
 
-class NeutronFloatingHandler(BaseAddressHandler):
+class NeutronFloatingHandler(base.BaseAddressHandler):
     """Handler for Neutron's notifications"""
     __plugin_name__ = 'neutron_floatingip'
 
