@@ -30,8 +30,11 @@ cfg.CONF.register_opts([
     cfg.ListOpt('notification-topics', default=['notifications']),
     cfg.StrOpt('control-exchange', default='nova'),
     cfg.StrOpt('zone-id'),
-    cfg.MultiStrOpt('format', default=[
-                    '%(octet0)s-%(octet1)s-%(octet2)s-%(octet3)s.%(zone)s'])
+    cfg.MultiStrOpt('formatv4'),
+    cfg.MultiStrOpt('format', deprecated_for_removal=True,
+                    deprecated_reason="Replaced by 'formatv4/formatv6'",
+                    ),
+    cfg.MultiStrOpt('formatv6')
 ], group='handler:nova_fixed')
 
 
